import 'dart:convert';

import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:scrobbles/config/settings.dart';
import 'package:scrobbles/cubit/data_discoveries_cubit.dart';
import 'package:scrobbles/models/discoveries.dart';
import 'package:scrobbles/ui/widgets/card_content.dart';
import 'package:scrobbles/ui/widgets/charts/discoveries_artists.dart';
import 'package:scrobbles/ui/widgets/charts/discoveries_tracks.dart';

class CardDiscoveries extends StatelessWidget {
  const CardDiscoveries({super.key});

  @override
  Widget build(BuildContext context) {
    final int daysCount = Settings.discoveriesDaysCount;

    return BlocProvider<DataDiscoveriesCubit>(
      create: (BuildContext context) => DataDiscoveriesCubit(),
      child: BlocBuilder<DataDiscoveriesCubit, DataDiscoveriesState>(
        builder: (BuildContext context, DataDiscoveriesState state) {
          final TextTheme textTheme = Theme.of(context).primaryTextTheme;

          return CardContent(
            color: Theme.of(context).colorScheme.surface,
            title: 'discoveries_title'.tr(
              namedArgs: {
                'daysCount': daysCount.toString(),
              },
            ),
            content: Column(
              mainAxisSize: MainAxisSize.min,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  'discoveries_artists_title',
                  style: textTheme.titleMedium!.apply(fontWeightDelta: 2),
                ).tr(),
                const SizedBox(height: 8),
                ChartDiscoveriesArtists(
                  chartData:
                      DiscoveriesData.fromJson(jsonDecode(state.discoveries.toString())),
                  isLoading: false,
                ),
                const SizedBox(height: 8),
                Text(
                  'discoveries_tracks_title',
                  style: textTheme.titleMedium!.apply(fontWeightDelta: 2),
                ).tr(),
                const SizedBox(height: 8),
                ChartDiscoveriesTracks(
                  chartData:
                      DiscoveriesData.fromJson(jsonDecode(state.discoveries.toString())),
                  isLoading: false,
                ),
              ],
            ),
          );
        },
      ),
    );
  }
}
