import 'dart:convert';

import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:scrobbles/config/settings.dart';
import 'package:scrobbles/cubit/data_timeline_cubit.dart';
import 'package:scrobbles/models/timeline.dart';
import 'package:scrobbles/ui/widgets/card_content.dart';
import 'package:scrobbles/ui/widgets/charts/timeline_counts.dart';
import 'package:scrobbles/ui/widgets/charts/timeline_eclecticism.dart';

class CardTimeline extends StatelessWidget {
  const CardTimeline({super.key});

  @override
  Widget build(BuildContext context) {
    final int daysCount = Settings.timelineDaysCount;

    return BlocProvider<DataTimelineCubit>(
      create: (BuildContext context) => DataTimelineCubit(),
      child: BlocBuilder<DataTimelineCubit, DataTimelineState>(
        builder: (BuildContext context, DataTimelineState state) {
          return CardContent(
            color: Theme.of(context).colorScheme.surface,
            title: 'timeline_title'.tr(
              namedArgs: {
                'daysCount': daysCount.toString(),
              },
            ),
            content: Stack(
              children: [
                ChartTimelineCounts(
                  chartData: TimelineData.fromJson(jsonDecode(state.timeline.toString())),
                  isLoading: false,
                ),
                ChartTimelineEclecticism(
                  chartData: TimelineData.fromJson(jsonDecode(state.timeline.toString())),
                  isLoading: false,
                ),
              ],
            ),
          );
        },
      ),
    );
  }
}
