import 'dart:convert';

import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:scrobbles/config/settings.dart';
import 'package:scrobbles/cubit/data_top_artists_cubit.dart';
import 'package:scrobbles/models/topartists.dart';
import 'package:scrobbles/ui/widgets/card_content.dart';
import 'package:scrobbles/ui/widgets/charts/top_artists.dart';

class CardTopArtists extends StatelessWidget {
  const CardTopArtists({super.key});

  @override
  Widget build(BuildContext context) {
    final int daysCount = Settings.topArtistsDaysCount;

    return BlocProvider<DataTopArtistsCubit>(
      create: (BuildContext context) => DataTopArtistsCubit(),
      child: BlocBuilder<DataTopArtistsCubit, DataTopArtistsState>(
        builder: (BuildContext context, DataTopArtistsState state) {
          return CardContent(
            color: Theme.of(context).colorScheme.surface,
            title: 'top_artists_title'.tr(
              namedArgs: {
                'daysCount': daysCount.toString(),
              },
            ),
            content: ChartTopArtists(
              chartData: TopArtistsData.fromJson(jsonDecode(state.topArtists.toString())),
              isLoading: false,
            ),
          );
        },
      ),
    );
  }
}
